@@ -1,14 +1,19 @@
 package Bio::Epithelium::Cell; 
 
 sub new {
-	my ($class, @g) = @_;
+	my ($class) = @_;
 
-	my $self = { genomes => @g, };
+	my $self = {};
 
 	$class = ref($class) || $class;
 
 	bless $self, $class;
 }
 
+sub has_nucleus {
+	my ($self) = @_;
+
+	return 0;
+}
 
 1;
