@@ -1,9 +1,9 @@
 package Bio::Epithelium::CellSystem; 
 
 sub new {
-	my ($class, @g) = @_;
+	my ($class, @cells) = @_;
 
-	my $self = { genomes => @g, };
+	my $self = { cells => @cells, };
 
 	$class = ref($class) || $class;
 
