@@ -5,8 +5,8 @@ use parent 'Bio::Epithelium::CellSystem';
 ### specialize into different epithelium classes
 
 sub new {
-	my ($class, @genomes) = @_;
-        my $self = $class->SUPER::new(@genomes);
+	my ($class, @cells) = @_;
+        my $self = $class->SUPER::new(@cells);
 
 }
 
